summaryrefslogtreecommitdiffstats
path: root/o3d
diff options
context:
space:
mode:
authorgspencer@google.com <gspencer@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2009-11-03 00:12:33 +0000
committergspencer@google.com <gspencer@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2009-11-03 00:12:33 +0000
commit84f8e7836a88f4b0753f9dca164613141ef16a90 (patch)
tree77a8bdd6efe1dad777cd31f4ed4f20f8d0dfaad9 /o3d
parente75e8afa0cf126ca22e403874a22249d51b86219 (diff)
downloadchromium_src-84f8e7836a88f4b0753f9dca164613141ef16a90.zip
chromium_src-84f8e7836a88f4b0753f9dca164613141ef16a90.tar.gz
chromium_src-84f8e7836a88f4b0753f9dca164613141ef16a90.tar.bz2
Put back some scons files that the docs build parses, but rename them
with ".manifest", since we no longer have a scons build. We should probably change the code that parses these to be simpler someday. Review URL: http://codereview.chromium.org/341073 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@30774 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'o3d')
-rwxr-xr-xo3d/documentation/build_docs.py4
-rw-r--r--o3d/documentation/get_docs_files.py12
-rw-r--r--o3d/plugin/idl_list.manifest92
-rw-r--r--o3d/samples/o3djs/js_list.manifest63
4 files changed, 163 insertions, 8 deletions
diff --git a/o3d/documentation/build_docs.py b/o3d/documentation/build_docs.py
index abf7046..3022922 100755
--- a/o3d/documentation/build_docs.py
+++ b/o3d/documentation/build_docs.py
@@ -346,8 +346,8 @@ def main(argv):
os.environ['PYTHONPATH'] = pythonpath
- js_list_filename = MakePath('..', 'samples', 'o3djs', 'js_list.scons')
- idl_list_filename = MakePath('..', 'plugin', 'idl_list.scons')
+ js_list_filename = MakePath('..', 'samples', 'o3djs', 'js_list.manifest')
+ idl_list_filename = MakePath('..', 'plugin', 'idl_list.manifest')
js_list_basepath = os.path.dirname(js_list_filename)
idl_list_basepath = os.path.dirname(idl_list_filename)
diff --git a/o3d/plugin/idl_list.manifest b/o3d/plugin/idl_list.manifest
new file mode 100644
index 0000000..579778e
--- /dev/null
+++ b/o3d/plugin/idl_list.manifest
@@ -0,0 +1,92 @@
+# Copyright 2009, Google Inc.
+# All rights reserved.
+#
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions are
+# met:
+#
+# * Redistributions of source code must retain the above copyright
+# notice, this list of conditions and the following disclaimer.
+# * Redistributions in binary form must reproduce the above
+# copyright notice, this list of conditions and the following disclaimer
+# in the documentation and/or other materials provided with the
+# distribution.
+# * Neither the name of Google Inc. nor the names of its
+# contributors may be used to endorse or promote products derived from
+# this software without specific prior written permission.
+#
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+
+
+O3D_IDL_SOURCES = [
+ 'idl/bitmap.idl',
+ 'idl/bounding_box.idl',
+ 'idl/buffer.idl',
+ 'idl/canvas.idl',
+ 'idl/canvas_paint.idl',
+ 'idl/canvas_shader.idl',
+ 'idl/clear_buffer.idl',
+ 'idl/client.idl',
+ 'idl/counter.idl',
+ 'idl/cursor.idl',
+ 'idl/curve.idl',
+ 'idl/display_mode.idl',
+ 'idl/draw_context.idl',
+ 'idl/draw_element.idl',
+ 'idl/draw_list.idl',
+ 'idl/draw_pass.idl',
+ 'idl/effect.idl',
+ 'idl/element.idl',
+ 'idl/event.idl',
+ 'idl/field.idl',
+ 'idl/file_request.idl',
+ 'idl/function.idl',
+ 'idl/material.idl',
+ 'idl/matrix4_axis_rotation.idl',
+ 'idl/matrix4_composition.idl',
+ 'idl/matrix4_scale.idl',
+ 'idl/matrix4_translation.idl',
+ 'idl/named.idl',
+ 'idl/pack.idl',
+ 'idl/param_array.idl',
+ 'idl/param.idl',
+ 'idl/param_object.idl',
+ 'idl/param_operation.idl',
+ 'idl/plugin.idl',
+ 'idl/primitive.idl',
+ 'idl/ray_intersection_info.idl',
+ 'idl/render_event.idl',
+ 'idl/render_node.idl',
+ 'idl/render_surface.idl',
+ 'idl/render_surface_set.idl',
+ 'idl/sampler.idl',
+ 'idl/shape.idl',
+ 'idl/skin.idl',
+ 'idl/standard_param.idl',
+ 'idl/state.idl',
+ 'idl/state_set.idl',
+ 'idl/stream.idl',
+ 'idl/stream_bank.idl',
+ 'idl/texture.idl',
+ 'idl/tick_event.idl',
+ 'idl/transform.idl',
+ 'idl/tree_traversal.idl',
+ 'idl/types.idl',
+ 'idl/vector.idl',
+ 'idl/vertex_source.idl',
+ 'idl/viewport.idl',
+ 'idl/archive_request.idl',
+ 'idl/raw_data.idl',
+]
+
+Export('O3D_IDL_SOURCES')
diff --git a/o3d/samples/o3djs/js_list.manifest b/o3d/samples/o3djs/js_list.manifest
new file mode 100644
index 0000000..c5fad39
--- /dev/null
+++ b/o3d/samples/o3djs/js_list.manifest
@@ -0,0 +1,63 @@
+# Copyright 2009, Google Inc.
+# All rights reserved.
+#
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions are
+# met:
+#
+# * Redistributions of source code must retain the above copyright
+# notice, this list of conditions and the following disclaimer.
+# * Redistributions in binary form must reproduce the above
+# copyright notice, this list of conditions and the following disclaimer
+# in the documentation and/or other materials provided with the
+# distribution.
+# * Neither the name of Google Inc. nor the names of its
+# contributors may be used to endorse or promote products derived from
+# this software without specific prior written permission.
+#
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+
+O3D_JS_SOURCES = [
+ 'arcball.js',
+ 'base.js',
+ 'camera.js',
+ 'canvas.js',
+ 'debug.js',
+ 'dump.js',
+ 'effect.js',
+ 'element.js',
+ 'error.js',
+ 'event.js',
+ 'fps.js',
+ 'io.js',
+ 'loader.js',
+ 'material.js',
+ 'math.js',
+ 'pack.js',
+ 'particles.js',
+ 'performance.js',
+ 'picking.js',
+ 'primitives.js',
+ 'quaternions.js',
+ 'rendergraph.js',
+ 'scene.js',
+ 'serialization.js',
+ 'shape.js',
+ 'simple.js',
+ 'test.js',
+ 'texture.js',
+ 'util.js',
+]
+
+Export('O3D_JS_SOURCES');
+
diff --git a/o3d/documentation/get_docs_files.py b/o3d/documentation/get_docs_files.py
index f4bc31d..90fcefc 100644
--- a/o3d/documentation/get_docs_files.py
+++ b/o3d/documentation/get_docs_files.py
@@ -78,7 +78,7 @@ def Import(filename):
def GetIdlFiles():
- idl_list_filename = os.path.join('..', 'plugin', 'idl_list.scons')
+ idl_list_filename = os.path.join('..', 'plugin', 'idl_list.manifest')
idl_list_basepath = os.path.dirname(idl_list_filename)
Import(idl_list_filename)
idl_files = AppendBasePath(idl_list_basepath, GlobalsDict['O3D_IDL_SOURCES'])
@@ -86,18 +86,18 @@ def GetIdlFiles():
def GetJsFiles():
- js_list_filename = os.path.join('..', 'samples', 'o3djs', 'js_list.scons')
+ js_list_filename = os.path.join('..', 'samples', 'o3djs', 'js_list.manifest')
js_list_basepath = os.path.dirname(js_list_filename)
Import(js_list_filename)
o3djs_files = AppendBasePath(js_list_basepath, GlobalsDict['O3D_JS_SOURCES'])
return o3djs_files
# Read in the scons files (which are just really simple python files),
# and scrape out the file lists.
-# TODO(gspencer): Once we no longer use the scons build, rework this
-# so that the lists are just python lists so we can just do a simple
-# eval instead of having to emulate scons import.
+# TODO(gspencer): Since we no longer use the scons build, we should
+# rework this so that the lists are just python lists so we can just
+# do a simple eval instead of having to emulate scons import.
def main(argv):
files = []
if argv[0] == '--js':
@@ -86,18 +86,18 @@ def GetIdlFiles():
o3djs_files = AppendBasePath(js_list_basepath, GlobalsDict['O3D_JS_SOURCES'])
return o3djs_files
-# Read in the scons files (which are just really simple python files),
+# Read in the manifest files (which are just really simple python files),
# and scrape out the file lists.